"use strict";
exports.startOfWeekYear = void 0;

var _index = require("../startOfWeekYear.js");
var _index2 = require("./_lib/convertToFP.js"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const startOfWeekYear = (exports.startOfWeekYear = (0, _index2.convertToFP)(
  _index.startOfWeekYear,
  1,
));
