// This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.
import { millisecondsToSeconds as fn } from "../millisecondsToSeconds.mjs";
import { convertToFP } from "./_lib/convertToFP.mjs";

export const millisecondsToSeconds = convertToFP(fn, 1);

// Fallback for modularized imports:
export default millisecondsToSeconds;
