"use strict";
exports.getTime = void 0;

var _index = require("../getTime.js");
var _index2 = require("./_lib/convertToFP.js"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const getTime = (exports.getTime = (0, _index2.convertToFP)(_index.getTime, 1));
