export declare const roundToNearestMinutesWithOptions: import("./types.js").FPFn2<
  Date,
  | import("../roundToNearestMinutes.js").RoundToNearestMinutesOptions
  | undefined,
  string | number | Date
>;
