"use strict";
exports.startOfSecond = void 0;

var _index = require("../startOfSecond.js");
var _index2 = require("./_lib/convertToFP.js"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const startOfSecond = (exports.startOfSecond = (0, _index2.convertToFP)(
  _index.startOfSecond,
  1,
));
