"use strict";
exports.eachWeekOfInterval = void 0;

var _index = require("../eachWeekOfInterval.js");
var _index2 = require("./_lib/convertToFP.js"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const eachWeekOfInterval = (exports.eachWeekOfInterval = (0,
_index2.convertToFP)(_index.eachWeekOfInterval, 1));
