"use strict";
exports.differenceInCalendarDays = void 0;

var _index = require("../differenceInCalendarDays.js");
var _index2 = require("./_lib/convertToFP.js"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const differenceInCalendarDays = (exports.differenceInCalendarDays = (0,
_index2.convertToFP)(_index.differenceInCalendarDays, 2));
