// This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.
import { min as fn } from "../min.mjs";
import { convertToFP } from "./_lib/convertToFP.mjs";

export const min = convertToFP(fn, 1);

// Fallback for modularized imports:
export default min;
