"use strict";
exports.millisecondsToHours = void 0;

var _index = require("../millisecondsToHours.js");
var _index2 = require("./_lib/convertToFP.js"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const millisecondsToHours = (exports.millisecondsToHours = (0,
_index2.convertToFP)(_index.millisecondsToHours, 1));
