"use strict";
exports.differenceInCalendarISOWeekYears = void 0;

var _index = require("../differenceInCalendarISOWeekYears.js");
var _index2 = require("./_lib/convertToFP.js"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const differenceInCalendarISOWeekYears =
  (exports.differenceInCalendarISOWeekYears = (0, _index2.convertToFP)(
    _index.differenceInCalendarISOWeekYears,
    2,
  ));
