// This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.
import { eachMinuteOfInterval as fn } from "../eachMinuteOfInterval.mjs";
import { convertToFP } from "./_lib/convertToFP.mjs";

export const eachMinuteOfInterval = convertToFP(fn, 1);

// Fallback for modularized imports:
export default eachMinuteOfInterval;
